stm32-metapac

Crates

git

Versions

stm32h533re

Flavors

Ioretr

Struct Ioretr 

#[repr(transparent)]
pub struct Ioretr(pub u32);
PWR I/O retention register.

Tuple Fields

0: u32

Implementations



impl Ioretr

pub const fn ioreten(&self) -> bool

IO retention enable: When entering into standby mode, the output is sampled, and apply to the output IO during the standby power mode. Note: the IO state is not retained if the DBG_STANDBY bit is set in DBGMCU_CR register.

pub const fn set_ioreten(&mut self, val: bool)

IO retention enable: When entering into standby mode, the output is sampled, and apply to the output IO during the standby power mode. Note: the IO state is not retained if the DBG_STANDBY bit is set in DBGMCU_CR register.

pub const fn jtagioreten(&self) -> bool

IO retention enable for JTAG IOs when entering into standby mode, the output is sampled, and apply to the output IO during the standby power mode.

pub const fn set_jtagioreten(&mut self, val: bool)

IO retention enable for JTAG IOs when entering into standby mode, the output is sampled, and apply to the output IO during the standby power mode.